.. image:: https://github.com/scrapy/scrapy/raw/master/artwork/scrapy-logo.jpg
   :width: 400px

======
Scrapyer
======

Overview
========

Scrapyer A library that encapsulates components based on the scrapy framework
